import * as React from 'react';
import * as dhx from '../../ext/dhtmlx_suite/codebase/suite.js';
import GrapheConfiguration from './model/GrapheConfiguration';

interface DhtmlxBarChartProps  {
  text?: string;
  bindToSampleData?: boolean;

  /** données du graphique
   * @see  https://docs.dhtmlx.com/suite/chart__initialization.html
   */
  data?: any[];

  /** configuration du graphique
   * @see  https://docs.dhtmlx.com/suite/chart__initialization.html
   */
  config?: GrapheConfiguration;
}

/**
 * Composant graphique Bar  
 */
export default class DhtmlxBarChart extends React.PureComponent<DhtmlxBarChartProps> {

  protected el: HTMLDivElement;
  private dhxComponent;
  constructor(props: DhtmlxBarChartProps) {
    super(props);
  }

  public componentDidCatch(error: Error | null, info: object) {
    Logger.logError('DhtmlxBarChart', error, info);
  }

  public componentDidMount() {
    window.dhx = dhx;
    const element = this.el;
    element.id = this.getUniqueId();
    if (this.props.bindToSampleData === true) {
      this.dhxComponent = new dhx.Chart(element.id, this.getSampleConfig());
      this.dhxComponent.data.parse(this.getSampleData());
    } else {
      this.dhxComponent = new dhx.Chart(element.id, this.props.config);
      this.dhxComponent.data.parse(this.props.data);
    }
  }

  public componentWillUnmount() {
    this.dhxComponent.destructor();
  }

  public render() {

    return (
      <div
        ref={(el) => this.el = el}
        style={this.props.style} >
      </div >
    );
  }

  private getSampleConfig() {
    return {
      type: 'bar',
      scales: {
        bottom: {
          text: 'month'
        },
        left: {
          maxTicks: 10,
          max: 100,
          min: 0
        }
      },
      series: [
        {
          id: 'A',
          value: 'company C',
          color: '#5E83BA',
          pointType: 'circle',
          fill: '#5E83BA',
          barWidth: 35
        }
      ]
    };
  }


  private getSampleData() {

    return [
      { month: '`02', 'company A': 20, 'company B': 52, 'company C': 72, 'company D': 34 },
      { month: '`03', 'company A': 5, 'company B': 33, 'company C': 90, 'company D': 55 },
      { month: '`04', 'company A': 55, 'company B': 30, 'company C': 81, 'company D': 66 },
      { month: '`05', 'company A': 30, 'company B': 11, 'company C': 62, 'company D': 22 },
      { month: '`06', 'company A': 27, 'company B': 14, 'company C': 68, 'company D': 70 },
      { month: '`07', 'company A': 32, 'company B': 31, 'company C': 64, 'company D': 50 },
      { month: '`08', 'company A': 50, 'company B': 22, 'company C': 30, 'company D': 80 },
      { month: '`09', 'company A': 12, 'company B': 19, 'company C': 65, 'company D': 48 },
      { month: '`10', 'company A': 10, 'company B': 24, 'company C': 50, 'company D': 66 },
      { month: '`11', 'company A': 17, 'company B': 40, 'company C': 78, 'company D': 55 }
    ];
  }


  private getUniqueId() {
    function generator() {
      return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
    }
    return generator() + generator() + '-' + generator() + '-' + generator() + '-' + generator() + '-' + generator() +
      generator() + generator();
  }

}
