export default interface Series {
  id: string;
  value: string;
  /**
  sets the type of the point of the data item. There are the following point types:"circle","rect","triangle","rhombus","simpleRect","simpleCircle","empty"
  */
  pointType: string;
  fill: string;
  text?: string;
  barWidth: number;

  /**the color of lines between sectors of a chart */
  stroke?: string;
  strokeWidth?: number;

  /** defines, whether a series is active/inactive */
  active?: boolean;

  /** shows/hides values of data items in bars of the Bar chart */
  showText?: boolean;

  /** defines whether a stacked chart will be rendered (Bar) */
  stacked?: boolean;

  /** the color of the series outline or points to the property in a data set that defines the color of a pie/donut sector */
  color?: string;


  /** adds a style class for a series */
  css?: string;



  /** sets a base line for rendering data items (bars in Bar chart) */
  baseLine?: number;

  /** transparency of the series filling (Area, Bar, Radar) */
  alpha?: number;

  /** sets the dashed type for a series line */
  dashed?: boolean;

  /**  shows/hides lines used to "connect" chart sectors with labels  */
  useLines?: boolean;

  /** paddings between a chart and its initial position */
  paddings: number;

  /** shows values of data items in tooltips, true by default */
  tooltip?: boolean;

  /**a function that defines a template for showing values of data items in tooltip */
  tooltipTemplate(e: React.FormEvent<HTMLInputElement>): string;

}
